<?php
/**
 * Generates requests to send to iPay.
 *
 * @author   Moses King'ori <moseskariuki2119@gmail.com>
 * @category Class
 * @package  Hotelier/Classes/Payment
 * @version  1.0.0
 */

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

if (!class_exists('HTL_Gateway_Ipay_Request')):

/**
 * HTL_Gateway_Ipay_Request Class
 */
	class HTL_Gateway_Ipay_Request {

		/**
		 * Stores line items to send to iPay
		 * @var array
		 */
		protected $line_items = array();

		/**
		 * Pointer to gateway making the request
		 * @var HTL_Gateway_Ipay
		 */
		protected $gateway;

		/**
		 * Endpoint for requests from iPay
		 * @var string
		 */
		protected $notify_url;

		/**
		 * Constructor
		 * @param HTL_Gateway_Ipay $gateway
		 */
		public function __construct($gateway) {
			$this->gateway = $gateway;
			$this->notify_url = HTL()->api_request_url('HTL_Gateway_Ipay');
		}

		/**
		 * Get the iPay request URL for an reservation
		 * @param  HTL_Reservation  $reservation
		 * @param  boolean $sandbox
		 * @return string
		 */
		public function get_request_url($reservation, $sandbox = false) {

			$live = $this->gateway->testmode ? "0" : "1";

			$mer = $this->gateway->merchantname;
			$tel = $reservation->guest_telephone;

			$tel = str_replace("-", "", $tel);
			$tel = str_replace(array(' ', '<', '>', '&', '{', '}', '*', "+", '!', '@', '#', "$", '%', '^', '&'), "", $tel);
			$eml = $reservation->guest_email;
			$vid = $this->gateway->vid;
			$oid = $reservation->get_reservation_number();
			$inv = $oid;
			$p1 = $reservation->reservation_key;
			$p2 = '';
			$p3 = '';
			$p4 = '';

			HTL_Gateway_Ipay::log("Reservation Key: " . $p1);

			HTL_Gateway_Ipay::log("Return URL: " . $this->gateway->get_return_url($reservation));

			$curr = $reservation->get_reservation_currency();

			$ttl = $reservation->get_deposit() / 100;
			$crl = '0';
			$cst = '1';
			$cbk = $this->notify_url;
			$hsh = $this->gateway->hashkey;

			$datastring = $live . $oid . $inv . $ttl . $tel . $eml . $vid . $curr . $p1 . $p2 . $p3 . $p4 . $cbk . $cst . $crl;
			$hash = hash_hmac('sha1', $datastring, $hsh);

			$autopay = $this->gateway->autopay ? "1" : "0";

			$ipay_base = "";

			switch ($this->gateway->merchantcountry) {
			case 'ke':
				$ipay_base = "https://payments.ipayafrica.com/v3/ke";
				break;
			case 'tz':
				$ipay_base = "https://payments.elipa.co.tz/v3/tz";
				break;
			case 'ug':
				$ipay_base = "https://payments.elipa.co.ug/v3/ug";
				break;
			case 'tg':
				$ipay_base = "https://payments.elipa.tg/v1/v3/index.php/togo";
				break;

			default:
				exit();
			}

			// Plugin identifier
			$channel = "WPHotelier";

			$url = $ipay_base . "?live=" . $live . "&oid=" . $oid . "&inv=" . $inv . "&ttl=" . $ttl . "&tel=" . $tel . "&eml=" . $eml . "&vid=" . $vid . "&curr=" . $curr . "&p1=" . $p1 . "&p2=" . $p2 . "&p3=" . $p3 . "&p4=" . $p4 . "&cbk=" . $cbk . "&cst=" . $cst . "&crl=" . $crl . "&hsh=" . $hash . "&creditcard=" . $creditcard . "&bonga=". '1' . "&vooma=". '1' . "&channel=" . $channel . "&autopay=" . $autopay;

			HTL_Gateway_Ipay::log("iPay URL: " . $url);
			return $url;
		}

	}

endif;
